@@ -295,7 +295,7 @@ class HestiaPi(Sensor):
 
     @property
     def temperature_rate_of_change(self):
-        if len(self._temperature_history) > self._temperature_history_period:
+        if len(self._temperature_history) >= self._temperature_history_period:
             roc = math.rate_of_change(self._temperature_history)
             logging.debug('Temperature rate of change is {}.'.format(roc))
             return roc
@@ -461,7 +461,7 @@ class HestiaPi(Sensor):
         # self._boosting_heat = boost
         else:
             logging.info(f"Boosting disabled by switch. Switch state: {self._boosting_enabled_switch.state}. aux_enabled: {self.aux_enabled}")
-            
+
     def should_boost(self):
         if self.mode == HVAC.HEAT and self.temperature_rate_of_change and self.temperature_rate_of_change <= self.minimum_temp_rate_of_change:
             return True
